# coding: utf-8

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from landing_page_server_connector.models.optin_method import OptinMethod  # noqa: E501

class TestOptinMethod(unittest.TestCase):
    """OptinMethod unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testOptinMethod(self):
        """Test OptinMethod"""
        # inst = OptinMethod()

if __name__ == '__main__':
    unittest.main()
